/**
 * app.js
 */

// UI controllers

var tabGroup = Ti.UI.createTabGroup();
var win = Ti.UI.createWindow({
    title: "Bonjour Test Sample",
    backgroundColor: '#fff'
});
var label = Ti.UI.createLabel({
    top: 30,
    text: "the bonjour service has stopped.",
    color: "#333",
    font: {
        fontSize: 14
    }
});
var startButton = Ti.UI.createButton({
    top: 120,
    title: " start bonjour service ",
    borderColor: 'gray',
    font: {
        fontSize: 20
    }
});
var stopButton = Ti.UI.createButton({
    top: 160,
    title: " stop bonjour service ",
    borderColor: 'gray',
    font: {
        fontSize: 20
    }
});
var switchLabel = Ti.UI.createLabel({
    top: 220,
    text: "search switch ",
    color: "#333",
    font: {
        fontSize: 20
    }
});
var basicSwitch = Ti.UI.createSwitch({
    top: 245,
    value:false
});
var outlabel = Ti.UI.createLabel({
    top: 300,
    text: "no message",
    color: "#333",
    font: {
        fontSize: 20
    }
});
var tableView = Titanium.UI.createTableView({
    top: 400,
    style:Titanium.UI.iOS.TableViewStyle.GROUPED,
    data:[{title:'No services', hasChild:false}]
});
var tab = Ti.UI.createTab({
    title: "Bonjour Test",
    icon: 'assets/images/tab1.png',
    window: win
});

// event handlers

function clickStartButton(event) {
    label.text = "starting a bonjour service...";
    bonjourServer.start();
    label.text = Titanium.Platform.id + "\ncompleted to start the bonjour service.";

    basicSwitch.value = true;
}

function clickStopButton(event) {
    label.text = "stopping the bonjour service...";
    bonjourServer.stop();
    label.text = "the bonjour service has stopped.";
}

var services = null;
function updateList(e) {
    var data = [];
    services = e['services'];

    for (var i=0; i < services.length; i++) {
        var service = services[i];
        var row = Titanium.UI.createTableViewRow({
            title:service.name + "\n" + service.type + service.domain,
            service:i,
            font: {
                fontSize: 12
            }
        });

        if (service.socket == null || !service.socket.isValid) {
            service.resolve();
            if (service.socket) {
                service.socket.addEventListener('read', function (x) {
                    outlabel.color = 'red';
                    outlabel.text = x['data'].text;
                });
                service.socket.connect();
            }
        }

        data.push(row);
    }

    if (data.length === 0) {
        data.push(Titanium.UI.createTableViewRow({
            title:'No services'
        }));
    }

    tableView.setData(data);
};

// register events

startButton.addEventListener('click', clickStartButton);
stopButton.addEventListener('click', clickStopButton);
basicSwitch.addEventListener('change',function(e){
    if (basicSwitch.value) {
        bonjourServer.startSearch();
    }
    else {
        bonjourServer.stopSearch();
    }
});

tableView.addEventListener('click', function(r) {
    var service = services[r['rowData'].service];
    if (service && service.socket && service.socket.isValid) {
        Ti.API.info("writeSocket: "  + service.socket.hostName);
        service.socket.write('req:' + Titanium.Platform.id + ':' + (new Date()));
    }
});

Ti.App.addEventListener('recieve', function(e) {
    // recieve data from socket event
    outlabel.color = 'blue';
    outlabel.text = e.text;
});

// initialize bonjourService //////////////////////////////////

var BonjourService = require('bonjourServiceTiWorker');
var bonjourServer = new BonjourService({updatedEvent: updateList});

// make and open Window

win.add(label);
win.add(startButton);
win.add(stopButton);
win.add(switchLabel);
win.add(basicSwitch);
win.add(outlabel);
win.add(tableView);

tabGroup.addTab(tab);
tabGroup.open();

